Program rskala;
(****************************************************************)
(* Version 1.20: mit Befehlen "Kreis" und "Spiegel"             *)
(****************************************************************)
Const
   ZeichenMax = 127;
   LinienMax  =  15;
   HPGLBildMass=100;(* Fr d.Plotter:1mm=100 Einheiten fr 0.01mm Auflsung*)
Type
   LinienTyp   = Record
                    x1,y1,x2,y2:Real
                 End;
   ZeichenTyp  = Array[0..LinienMax] Of LinienTyp;
   ZeichensatzTyp= Array[0..ZeichenMax] Of ZeichenTyp;
   QTyp        = 0..3; (* Quadrant,in den eine Schrift gesetzt werden soll *)
                       (* 0: Schrift rechts oben vom angegebenen Punkt     *)
                       (* 1: links oben                                    *)
                       (* 2: links unten                                   *)
                       (* 3: rechts unten                                  *)
                       (* entsprechend den Quadranten im kartes.Koord.Sys. *)
Var
   Zeichensatz :Zeichensatztyp;(* Zeichensatz *)

   Sprache     :String ;(* Art der Ausgabe *)
   Spiegel     :String ;(* Ausgabe spiegeln: ON/OFF *)
   Bildhoehe   :Real   ;
   Bildweite   :Real   ;

   EinDateiName:String ;
   AusDateiName:String ;
   E           :Text   ;(* Name der Eingabedatei *)
   D           :Text   ;(* Name der Ausgabedatei *)
   Wort        :String ;
   HalbkreisWinkel:Real;(* AltGrad:180, NeuGrad:200 Grad fr pi *)

   PCount      :Integer;(* Zhler der Punkte fr emTeX *)
   altX        :Integer;(* Fr HPGL: x-Koordinate des letzten Punktes *)
   altY        :Integer;(* Fr HPGL: y- "          "   "       "      *)

(*************************************************************)
(*---------------- Kurze Rechenroutinen ---------------------*)
(*************************************************************)
Function NMOD(a,b:Integer):Integer;
Begin
   If a>0
   Then NMOD:=a MOD b
   Else NMOD:=(b-(-a MOD b)) MOD b;
End;(* NMOD *)
(************************************************************)
(* Folgende NINT-Funktion schneidet immer in negativer      *)
(* Richtung, so da der geschnittene Wert immer KLEINER ist *)
(* als der ursprngliche:                                   *)
(* Int(-2.2)=-2.0* Turbo-Berechnung     *                   *)
(* Int(-2.0)=-2.0                                           *)
(* NInt(-2.2)=-3.0 * mathematisch richtig *                 *)
(* NInt(-2.0)=-2.0                                          *)
(************************************************************)
Function NINT(a:Real):Real;
Begin
   If a>0
   Then NINT:=INT(a)
   Else Begin
      If Frac(a)=0
      Then NINT:=-INT(-a)
      Else NINT:=-INT(-a)-1
   End;
End;(* NINT *)
(************************************************************)
(* Folgende NFRAC-Funktion hat immer ein positives          *)
(* Ergebnis.                                                *)
(* Frac (-2.2)=-0.2 * Turbo-Berechnung     *                *)
(* Frac (-2.0)= 0                                           *)
(* NFrac(-2.2)= 0.8 * mathematisch richtig *                *)
(* NFrac(-2.0)= 0                                           *)
(************************************************************)
Function NFRAC(a:Real):Real;
Begin
   If a>0
   Then NFRAC:=Frac(a)
   Else Begin
      If Frac(a)=0
      Then NFRAC:=0
      Else NFRAC:=Frac(a)+1
   End;
End;(* NFRAC *)
(************************************************************)
(* Folgende NTRUNC-Funktion schneidet immer in negativer    *)
(* Richtung, so da der geschnittene Wert immer KLEINER ist *)
(* als der ursprngliche:                                   *)
(* Trunc(-2.2)=-2  * Turbo-Berechnung     *                 *)
(* Trunc(-2.0)=-2                                           *)
(* NTrunc(-2.2)=-3 * mathematisch richtig *                 *)
(* NTrunc(-2.0)=-2                                          *)
(************************************************************)
Function NTRUNC(a:Real):Integer;
Var x,VorKomma:Real;
Begin
   If a>0
   Then NTRUNC:=Trunc(a)
   Else Begin
      If Frac(a)=0
      Then NTRUNC:=-Trunc(-a)
      Else NTRUNC:=-Trunc(-a)-1
   End;
End;(* NTRUNC *)
(*************************************************************)
(* Folgende NROUND-Funktion rundet die Zahlen -0.5,-1.5,.... *)
(* immer in positiver Richtung (im Gegensatz zur eingebauten *)
(* Round-Funktion):                                          *)
(*  Round(-2.5)=-3 * Turbo-Berechnung     *                  *)
(* NRound(-2.5)=-2 * mathematisch richtig *                  *)
(*************************************************************)
Function NRound(a:Real):Integer;
Begin
   a:=a+0.5;
   NRound:=NTrunc(a);
End;(* NROUND *)
(**********************************************************)
(* Dienen dazu, neben Winkelangaben im Bogenma auch      *)
(* Angaben in AltGrad und Neugrad zu ermglichen, und zwar*)
(* in Abhngigkeit von der Variablen HALBKREISWINKEL:     *)
(* BogenMa:HalbKreisWinkel=3.14159...                    *)
(* AltGrad :      "        =180                           *)
(* NeuGrad :      "        =200                           *)
(**********************************************************)
Function Sinus(x:Real):Real;
Begin
   Sinus:=Sin(x/HalbKreisWinkel*pi)
End;

(**********************************************************)

Function Cosin(x:Real):Real;
Begin
   Cosin:=Cos(x/HalbKreisWinkel*pi)
End;

(**********************************************************)
(*-----------------Zeichensatz----------------------------*)
(**********************************************************)
(* Jedes Zeichen ist aus einer Reihe von Linien zusammen- *)
(* gesetzt. Sicher nicht die eleganteste Methode, aber am *)
(* schnellsten zu programmieren...                        *)
(* Wenn .x1=0 ist, ist das Zeichen fertig.                *)
(**********************************************************)
Procedure ZeichensatzInit(Var Zeichensatz:ZeichensatzTyp);
(*-------------------------------------------------------------*)
(* Um schnell einen kompletten Zeichensatz erstellen zu        *)
(* knnen, ist der Font selbst so aufgebaut, da jedes Zeichen *)
(* aus einer Reihe von Punkten aufgebaut ist, die mit A,B,C... *)
(* bezeichnet sind. Diese Punkte bilden einen Linienzug:       *)
(*                                                      *)
(*1000     W X Y Z [                                    *)
(* 875     U       V                                    *)
(* 750     S       T                                    *)
(* 625     Q       R                                    *)
(* 500     L M N O P                                    *)
(* 375     J       K                                    *)
(* 250     H       I                                    *)
(* 125     F       G                                    *)
(*   0     A B C D E   Neu ansetzen:"@"                 *)
(*         |   |   |                                    *)
(*         0 500 1000                                   *)
(********************************************************)
(* 1000      X---Z                                      *)
(* 875     U       V                                    *)
(* 750     |       |                                    *)
(* 625     Q       R                                    *)
(* 500       M---O                                      *)
(* 375     J       K                                    *)
(* 250     |       |                                    *)
(* 125     F       G                                    *)
(*   0       B---D                                      *)
(***********************************************************)
(* So ist das Zeichen "8" aus den Punkten OMQUXZVROKGDBFJM *)
(* zusammengesetzt.                                        *)
(* Das Zeichen "@" bedeutet: Neu ansetzen.                 *)
(* So ist das Zeichen "Y" aus den Punkten CN[@NW           *)
(* zusammengesetzt.                                        *)
(* Aufgabe der Routine ZEICHENSATZINIT ist es, aus dem     *)
(* String 'CN[@NW' die Koordinaten der Linien zu berechnen,*)
(* die das Zeichen "Y" ergeben:                            *)
(*                                * Linie C---N *          *)
(* ZeichenSatz[Ord(Y),0].x1:=500; * Punkt C *              *)
(*                      .y1:=  0; * Punkt C *              *)
(*                      .x2:=500; * Punkt N *              *)
(*                      .y2:=500; * Punkt N *              *)
(*                                * Linie N---[ *          *)
(* ZeichenSatz[Ord(Y),1].x1:=500; * Punkt N *              *)
(*                      .y1:=  0; * Punkt N *              *)
(*                      .x2:=500; * Punkt [ *              *)
(*                      .y2:=500; * Punkt [ *              *)
(* usw.                                                    *)
(*------------------------------------------------------------*)
Const
   (* Koordinaten der Punkte @,A,B,C,...,X,Y,Z,[ *)
   xKoord:Array['@'..'['] Of Integer=(0,0,250,500,750,1000,0,1000,0,1000,0,
                                      1000,0,250,500,750,1000,0,1000,0,1000,
                                      0,1000,0,250,500,750,1000);
   yKoord:Array['@'..'['] Of Integer=(0,0,0,0,0,0,125,125,250,250,375,375,
                                      500,500,500,500,500,625,625,750,750,
                                      875,875,1000,1000,1000,1000,1000);
Var
   ZSKurz:Array[0..ZeichenMax] Of String[20];(* ZeichenSatz in KurzForm *)
   Zeichen,Position,LinieNr:Integer;
Begin
   For Zeichen:=0 To ZeichenMax Do
      ZSKurz[Zeichen]:='';

   ZSKurz[32]      :='ABCDEFGHIJK'; (* alternativ: FAEG, SPC-Zeichen |_| *)
   ZSKurz[Ord('!')]:='YN@BD';
   ZSKurz[Ord('"')]:='WU@[V';
   ZSKurz[Ord('#')]:='XB@ZD@ST@HI';
   ZSKurz[Ord('$')]:='VZXUQMOKGDBF@XB@ZD';
   ZSKurz[Ord('%')]:='A[@UX@DG';
   ZSKurz[Ord('&')]:='EQUXZVROMJFBCI';
   ZSKurz[39]      :='UX';
   ZSKurz[Ord('(')]:='YSHC';
   ZSKurz[Ord(')')]:='YTIC';
   ZSKurz[Ord('*')]:='YC@LP@A[@WE';
   ZSKurz[Ord('+')]:='YC@LP';
   ZSKurz[Ord(',')]:='XGFVU';
   ZSKurz[Ord('-')]:='LP';
   ZSKurz[Ord('.')]:='CD';
   ZSKurz[Ord('/')]:='A[';
   ZSKurz[Ord('0')]:='UFBDGVZXU';
   ZSKurz[Ord('1')]:='DZM';
   ZSKurz[Ord('2')]:='UXZVRAE';
   ZSKurz[Ord('3')]:='W[NOKGDBF';
   ZSKurz[Ord('4')]:='DZHI';
   ZSKurz[Ord('5')]:='FBDGKOLW[';
   ZSKurz[Ord('6')]:='ZQFBDGKOMJ';
   ZSKurz[Ord('7')]:='W[A';
   ZSKurz[Ord('8')]:='OMQUXZVROKGDBFJM';
   ZSKurz[Ord('9')]:='ROMQUXZVKB';
   ZSKurz[Ord(':')]:='RP@GE';
   ZSKurz[Ord(';')]:='RP@GD';
   ZSKurz[Ord('<')]:='EL[';
   ZSKurz[Ord('=')]:='QR@JK';
   ZSKurz[Ord('>')]:='WPA';
   ZSKurz[Ord('?')]:='UXZVRONC';
   ZSKurz[Ord('@')]:='OMIVZXUFBDG';
   ZSKurz[Ord('A')]:='AYE@MO';
   ZSKurz[Ord('B')]:='WZVROKGDA@BX@MO';
   ZSKurz[Ord('C')]:='[YSHCE';
   ZSKurz[Ord('D')]:='WYTICA@XB';
   ZSKurz[Ord('E')]:='[WAE@LO';
   ZSKurz[Ord('F')]:='[WA@LO';
   ZSKurz[Ord('G')]:='VZXUFBEPL';
   ZSKurz[Ord('H')]:='WA@[E@LP';
   ZSKurz[Ord('I')]:='YC@XZ@BD';
   ZSKurz[Ord('J')]:='[GDBF';
   ZSKurz[Ord('K')]:='WA@[LE';
   ZSKurz[Ord('L')]:='WAE';
   ZSKurz[Ord('M')]:='AWC[E';
   ZSKurz[Ord('N')]:='AWE[';
   ZSKurz[Ord('O')]:='YSHCITY';
   ZSKurz[Ord('P')]:='AWZVROL';
   ZSKurz[Ord('Q')]:='YSHCITY@ME';
   ZSKurz[Ord('R')]:='AWZVROLE';
   ZSKurz[Ord('S')]:='VZXUQMOKGDBF';
   ZSKurz[Ord('T')]:='W[@YC';
   ZSKurz[Ord('U')]:='WFBDG[';
   ZSKurz[Ord('V')]:='WC[';
   ZSKurz[Ord('W')]:='WAYE[';
   ZSKurz[Ord('X')]:='WE@A[';
   ZSKurz[Ord('Y')]:='CN[@NW';
   ZSKurz[Ord('Z')]:='W[AE';
   ZSKurz[Ord('[')]:='ZXBD';
   ZSKurz[Ord('\')]:='WE';
   ZSKurz[Ord(']')]:='XZDB';
   ZSKurz[Ord('^')]:='SYT';
   ZSKurz[Ord('_')]:='AE';
   ZSKurz[Ord('`')]:='ZV';
   ZSKurz[Ord('a')]:='LOKGDBFHI@GE';
   (* alternativ: KOMJFBDG@PE oder JMOKE@GDBFHI *)
   ZSKurz[Ord('b')]:='WA@JMOKGDBF';
   ZSKurz[Ord('c')]:='KOMJFBDG';
   ZSKurz[Ord('d')]:='[E@KOMJFBDG';
   ZSKurz[Ord('e')]:='HIKOMJFDBG';
   ZSKurz[Ord('f')]:='ZYC@MO';
   ZSKurz[Ord('g')]:='FBDGKOMJHI';
   ZSKurz[Ord('h')]:='WA@JMOKE';
   ZSKurz[Ord('i')]:='MNCBD';
   ZSKurz[Ord('j')]:='MNCBF';
   ZSKurz[Ord('k')]:='WA@PHE';
   ZSKurz[Ord('l')]:='YCD';
   ZSKurz[Ord('m')]:='LA@JMOKE@NC';
   ZSKurz[Ord('n')]:='LA@JMOKE';
   ZSKurz[Ord('o')]:='JMOKGDBFJ';
   ZSKurz[Ord('p')]:='LA@JMOKIH';
   ZSKurz[Ord('q')]:='PE@IHJMOK';
   ZSKurz[Ord('r')]:='LA@JMOK';
   ZSKurz[Ord('s')]:='FBDGIHJMOK';
   ZSKurz[Ord('t')]:='YCD@MO';
   ZSKurz[Ord('u')]:='LFBDG@PE';
   ZSKurz[Ord('v')]:='LCP';
   ZSKurz[Ord('w')]:='LBNDP';
   ZSKurz[Ord('x')]:='LE@AP';
   ZSKurz[Ord('y')]:='LI@PIA';
   ZSKurz[Ord('z')]:='LPAE';
   ZSKurz[Ord('{')]:='ZYCD@MN';
   ZSKurz[Ord('|')]:='YC';
   ZSKurz[Ord('}')]:='XYCB@NO';
   ZSKurz[Ord('~')]:='UXV[';
   ZSKurz[127]     :='APLYPELAE';(* DIDHVN *)

   For Zeichen:=0 To ZeichenMax Do Begin
      For Position:=0 To LinienMax Do ZeichenSatz[Zeichen,Position].x1:=-1;

      If Length(ZSKurz[Zeichen])>1 Then Begin
         LinieNr:=0;
         For Position:=1 To Length(ZSKurz[Zeichen])-1 Do Begin
{            WriteLn(Zeichen,';',Position,';',ZSKurz[Zeichen,Position+1]);}
            If (ZSKurz[Zeichen,Position]<>'@')
            And (ZSKurz[Zeichen,Position+1]<>'@') Then Begin
               ZeichenSatz[Zeichen,LinieNr].x1:=xKoord[ZSKurz[Zeichen,Position]];
               ZeichenSatz[Zeichen,LinieNr].y1:=yKoord[ZSKurz[Zeichen,Position]];
               ZeichenSatz[Zeichen,LinieNr].x2:=xKoord[ZSKurz[Zeichen,Position+1]];
               ZeichenSatz[Zeichen,LinieNr].y2:=yKoord[ZSKurz[Zeichen,Position+1]];
               Inc(LinieNr);
            End;(* <>'@' *)
         End;(* For Position *)
      End;(* If Length>1 *)
   End;
(* ! *)
   Zeichensatz[33,0].x1:=450;
   Zeichensatz[33,0].y1:=100;
   Zeichensatz[33,0].x2:=550;
   Zeichensatz[33,0].y2:=100;

   Zeichensatz[33,1].x1:=450;
   Zeichensatz[33,1].y1:=0;
   Zeichensatz[33,1].x2:=450;
   Zeichensatz[33,1].y2:=100;

   Zeichensatz[33,2].x1:=550;
   Zeichensatz[33,2].y1:=0;
   Zeichensatz[33,2].x2:=550;
   Zeichensatz[33,2].y2:=100;

   Zeichensatz[33,3].x1:=450;
   Zeichensatz[33,3].y1:=0;
   Zeichensatz[33,3].x2:=550;
   Zeichensatz[33,3].y2:=0;

   Zeichensatz[33,4].x1:=500;
   Zeichensatz[33,4].y1:=250;
   Zeichensatz[33,4].x2:=500;
   Zeichensatz[33,4].y2:=1000;

(* . *)
   Zeichensatz[44,0].x1:=450;
   Zeichensatz[44,0].y1:=100;
   Zeichensatz[44,0].x2:=550;
   Zeichensatz[44,0].y2:=100;

   Zeichensatz[44,1].x1:=450;
   Zeichensatz[44,1].y1:=0;
   Zeichensatz[44,1].x2:=450;
   Zeichensatz[44,1].y2:=100;

   Zeichensatz[44,2].x1:=550;
   Zeichensatz[44,2].y1:=0;
   Zeichensatz[44,2].x2:=550;
   Zeichensatz[44,2].y2:=100;

   Zeichensatz[44,3].x1:=450;
   Zeichensatz[44,3].y1:=0;
   Zeichensatz[44,3].x2:=550;
   Zeichensatz[44,3].y2:=0;

   Zeichensatz[44,4].x1:=550;
   Zeichensatz[44,4].y1:=0;
   Zeichensatz[44,4].x2:=450;
   Zeichensatz[44,4].y2:=-100;

(* . *)
   Zeichensatz[46,0].x1:=450;
   Zeichensatz[46,0].y1:=100;
   Zeichensatz[46,0].x2:=550;
   Zeichensatz[46,0].y2:=100;

   Zeichensatz[46,1].x1:=450;
   Zeichensatz[46,1].y1:=0;
   Zeichensatz[46,1].x2:=450;
   Zeichensatz[46,1].y2:=100;

   Zeichensatz[46,2].x1:=550;
   Zeichensatz[46,2].y1:=0;
   Zeichensatz[46,2].x2:=550;
   Zeichensatz[46,2].y2:=100;

   Zeichensatz[46,3].x1:=450;
   Zeichensatz[46,3].y1:=0;
   Zeichensatz[46,3].x2:=550;
   Zeichensatz[46,3].y2:=0;

(* : *)
   Zeichensatz[58,0].x1:=450;
   Zeichensatz[58,0].y1:=100;
   Zeichensatz[58,0].x2:=550;
   Zeichensatz[58,0].y2:=100;

   Zeichensatz[58,1].x1:=450;
   Zeichensatz[58,1].y1:=0;
   Zeichensatz[58,1].x2:=450;
   Zeichensatz[58,1].y2:=100;

   Zeichensatz[58,2].x1:=550;
   Zeichensatz[58,2].y1:=0;
   Zeichensatz[58,2].x2:=550;
   Zeichensatz[58,2].y2:=100;

   Zeichensatz[58,3].x1:=450;
   Zeichensatz[58,3].y1:=0;
   Zeichensatz[58,3].x2:=550;
   Zeichensatz[58,3].y2:=0;

   Zeichensatz[58,4].x1:=550;
   Zeichensatz[58,4].y1:=500;
   Zeichensatz[58,4].x2:=450;
   Zeichensatz[58,4].y2:=500;

   Zeichensatz[58,5].x1:=450;
   Zeichensatz[58,5].y1:=400;
   Zeichensatz[58,5].x2:=450;
   Zeichensatz[58,5].y2:=500;

   Zeichensatz[58,6].x1:=550;
   Zeichensatz[58,6].y1:=400;
   Zeichensatz[58,6].x2:=550;
   Zeichensatz[58,6].y2:=500;

   Zeichensatz[58,7].x1:=450;
   Zeichensatz[58,7].y1:=400;
   Zeichensatz[58,7].x2:=550;
   Zeichensatz[58,7].y2:=400;

(* ; *)
   Zeichensatz[59,0].x1:=450;
   Zeichensatz[59,0].y1:=100;
   Zeichensatz[59,0].x2:=550;
   Zeichensatz[59,0].y2:=100;

   Zeichensatz[59,1].x1:=450;
   Zeichensatz[59,1].y1:=0;
   Zeichensatz[59,1].x2:=450;
   Zeichensatz[59,1].y2:=100;

   Zeichensatz[59,2].x1:=550;
   Zeichensatz[59,2].y1:=0;
   Zeichensatz[59,2].x2:=550;
   Zeichensatz[59,2].y2:=100;

   Zeichensatz[59,3].x1:=450;
   Zeichensatz[59,3].y1:=0;
   Zeichensatz[59,3].x2:=550;
   Zeichensatz[59,3].y2:=0;

   Zeichensatz[59,4].x1:=550;
   Zeichensatz[59,4].y1:=500;
   Zeichensatz[59,4].x2:=450;
   Zeichensatz[59,4].y2:=500;

   Zeichensatz[59,5].x1:=450;
   Zeichensatz[59,5].y1:=400;
   Zeichensatz[59,5].x2:=450;
   Zeichensatz[59,5].y2:=500;

   Zeichensatz[59,6].x1:=550;
   Zeichensatz[59,6].y1:=400;
   Zeichensatz[59,6].x2:=550;
   Zeichensatz[59,6].y2:=500;

   Zeichensatz[59,7].x1:=450;
   Zeichensatz[59,7].y1:=400;
   Zeichensatz[59,7].x2:=550;
   Zeichensatz[59,7].y2:=400;

   Zeichensatz[59,4].x1:=550;
   Zeichensatz[59,4].y1:=0;
   Zeichensatz[59,4].x2:=450;
   Zeichensatz[59,4].y2:=-100;

End;(* Proc ZeichensatzInit *)

(**********************************************************)
(* ------------------Ausgaberoutinen----------------------*)
(**********************************************************)

Procedure AusgabeInit(Var D:Text;Sprache:String;BildWeite,BildHoehe:Real);
Begin

   If Sprache='EMTEX'
   Then Begin
         PCount:=1;
         WriteLn('Die Ausgabe in eine emTeX-Datei beginnt.');
         WriteLn('Beginning output into emTeX file.');
         WriteLn(D,'\documentstyle[emlines2,german]{article}');
         WriteLn(D,'\textwidth=180mm    ');
         WriteLn(D,'\textheight=250mm   ');
         WriteLn(D,'\evensidemargin=0mm ');
         WriteLn(D,'\oddsidemargin=0mm  ');
         WriteLn(D,'\topmargin=0mm      ');
         WriteLn(D,'\pagestyle{empty}   ');
         WriteLn(D,'\begin{document}    ');
         WriteLn(D,'\unitlength=1.00mm  ');
         WriteLn(D,'\special{em:linewidth 0.4pt}');
         WriteLn(D,'\linethickness{0.4pt}');
         WriteLn(D,'\begin{picture}(',BildWeite:6:2,',',Bildhoehe:6:2,')');
   End(* emTeX *)
   Else If Sprache='TEXCAD'
   Then Begin
         PCount:=1;
         WriteLn('Die Ausgabe in eine TeXCAD-Datei beginnt.');
         WriteLn('Beginning output into TeXCAD file.');
         WriteLn(D,'\unitlength=1.00mm');
         WriteLn(D,'\special{em:linewidth 0.4pt}');
         WriteLn(D,'\linethickness{0.4pt}');
         WriteLn(D,'\begin{picture}(',BildWeite:6:2,',',Bildhoehe:6:2,')');
   End(* TeXCAD *)
   Else If Sprache='LATEX'
   Then Begin
         PCount:=1;
         WriteLn('Die Ausgabe in eine LaTeX-Datei beginnt.');
         WriteLn('Beginning output into LaTeX file.');
         WriteLn(D,'\documentclass{article}');
         WriteLn(D,'\usepackage{epic}\usepackage{eepic}');
         WriteLn(D,'\textwidth=180mm    ');
         WriteLn(D,'\textheight=250mm   ');
         WriteLn(D,'\evensidemargin=0mm ');
         WriteLn(D,'\oddsidemargin=0mm  ');
         WriteLn(D,'\topmargin=0mm      ');
         WriteLn(D,'\pagestyle{empty}   ');
         WriteLn(D,'\begin{document}    ');
         WriteLn(D,'\unitlength=1.00mm  ');
         WriteLn(D,'\linethickness{0.4pt}');         
         WriteLn(D,'\begin{picture}(180,250)');
   End(* LaTeX *)
   Else If Sprache='HPGL'
   Then Begin
            WriteLn('Die Ausgabe in eine HPGL-Datei beginnt.');
            WriteLn('Beginning output into HPGL file.');
            WriteLn('Papiergre/paper size..: A4 quer/landscape');  (* nutzbar 250x180mm     *)
            WriteLn('Auflsung/resolution....: 1/',HPGLBildMass,'mm');
            WriteLn(D,'SC0,',250*HPGLBildMass,',',0,',',180*HPGLBildMass,';');

                                               (* HPGLBildMass=100:     *)
                                               (* 250x180mm entsprechen *)
                                               (* 25000x18000 Einheiten *)
            WriteLn('Stift/pen...............: 1     ');
            WriteLn(D,'SP1;PU;');              (* Stift 1 whlen, anheben  *)
            AltX:=-1;
            AltY:=-1;
   End(* HPGL *)
   Else Begin
      Writeln('ERRORCODE #4 :');
      Writeln('Unbekannte Ausgabesprache angegeben!');
      Writeln('Unknown output language!');
   End;(* Else *)
End;(* Proc *)

(**********************************************************)
(*---------- Rcksetzen der Treiber, Schlieen der Dateien*)
(**********************************************************)

Procedure AusgabeExit(Sprache:String);
Begin
   If (Sprache='EMTEX') Then Begin
      WriteLn(D,'\end{picture}  ');
      WriteLn(D,'\end{document} ');
      Close(D);
   End
   Else If (Sprache='TEXCAD') Then Begin
      WriteLn(D,'\end{picture} ');
      Close(D);
   End   
   Else If (Sprache='LATEX') Then Begin
      WriteLn(D,'\end{picture}  ');
      WriteLn(D,'\end{document} ');
      Close(D);
   End
   Else If (Sprache='HPGL') Then Begin
      WriteLn(D,'SP0;');
      WriteLn(D,'PU;');
      Close(D);
   End;

End;(* Proc *)

(**********************************************************)
(*----- Ausgabe einer Linie-------------------------------*)
(**********************************************************)

Procedure AusLinie(Var D:Text;Sprache:String;Linie:LinienTyp;BildHoehe,BildWeite:Real);
Var
   AusGLinie:LinienTyp;
Begin
   AusGLinie:=Linie;

   With AusGLinie Do Begin
      If (Spiegel='ON')
      Then Begin
         x1:=-x1;
         x2:=-x2;
      End;(* Spiegel *)

      If ((Sprache='TEXCAD') Or (Sprache='EMTEX'))
      Then Begin
         x1:=x1+BildWeite/2;(* Positionierung in Seitenmitte *)
         y1:=y1+Bildhoehe/2;
         x2:=x2+BildWeite/2;
         y2:=y2+Bildhoehe/2;
         WriteLn(D,'\emline{',x1:5:2,'}{',y1:5:2,'}{',pCount,'}{',x2:5:2,'}{',y2:5:2,'}{',pCount+1,'}');
         pCount:=pCount+2;
      End;(* emTeX oder TeXCAD *)

      If (Sprache='LATEX')
      Then Begin
         x1:=x1+BildWeite/2;(* Positionierung in Seitenmitte *)
         y1:=y1+Bildhoehe/2;
         x2:=x2+BildWeite/2;
         y2:=y2+Bildhoehe/2;
         WriteLn(D,'\drawline(',x1:5:2,',',y1:5:2,')(',x2:5:2,',',y2:5:2,')');
      End;(* LaTeX *)

      If (Sprache='HPGL')
      Then Begin
         x1:=x1+BildWeite/2;(* Positionierung in Seitenmitte *)
         y1:=y1+BildHoehe/2;
         x2:=x2+BildWeite/2;
         y2:=y2+BildHoehe/2;
         x1:=x1*HPGLBildMass;(* Umrechnung mm --> Einheiten *)
         y1:=y1*HPGLBildMass;
         x2:=x2*HPGLBildMass;
         y2:=y2*HPGLBildMass;
         (****************************************************************)
         (* Es wird im foldenden nachgeprft, ob der Beginn der nchsten *)
         (* Linie gleich dem Ende der letzten Linie ist.                 *)
         (* Wenn ja, braucht nur noch das Ende der neuen Linie ange-     *)
         (* fahren zu werden:                                            *)
         (****************************************************************)
         If ((AltY=Round(y1)) AND (AltX=Round(x1))) (* Punkt1=alter Punkt *)
         Then Begin
            WriteLn(D,'PA',Round(x2),',',Round(y2),';');
            AltX:=Round(x2);
            AltY:=Round(y2);
         End
         (****************************************************************)
         (* Ebenso knnte (etwas unwahrscheinlich, auer beim Ausdruck   *)
         (* von Zeichen) das Ende der nchsten Linie gleich dem Ende der *)
         (* letzten Linie sein:                                          *)
         (****************************************************************)
         Else If ((AltY=Round(y2)) AND (AltX=Round(x2))) (* Punkt2=alter Punkt *)
         Then Begin
            WriteLn(D,'PA',Round(x1),',',Round(y1),';');
            AltX:=Round(x1);
            AltY:=Round(y1);
         End
         (****************************************************************)
         (* Sind beide Koordinaten der nchsten Linie verschieden vom    *)
         (* Endpunkt der letzten Linie, so mu ganz normal der Stift     *)
         (* angehoben, zum 1.Punkt gefahren, abgesenkt und zum 2.Punkt   *)
         (* gebracht werden:                                             *)
         (****************************************************************)
         Else Begin
            WriteLn(D,'PU;PA',Round(x1),',',Round(y1),';PD;');(* Beide Punkte vom alten Punkt verschieden *)
            WriteLn(D,'PA',Round(x2),',',Round(y2),';');
            AltX:=Round(x2);
            AltY:=Round(y2);
         End;(* If-ElseIf-Else-Kette *)

      End;(* HPGL *)
   End;(* With *)

   AusGLinie:=Linie;

End;(* Proc *)

(**********************************************************)
(*----Transformation derKoordinaten einer Linie-----------*)
(* Dehnen um die Faktoren w (Weite) und h (Hhe)          *)
(* Drehen um den Winkel phi                               *)
(* Verschieben um x,y                                     *)
(**********************************************************)

Procedure TransLinie(Var Linie:LinienTyp;x,y,w,h,phi:Real);
Var
   altx:Real;
   i,j:integer;
Begin
   With Linie Do Begin
      x1:=x1*w;x2:=x2*w;                   (* Stauchen *)
      y1:=y1*h;y2:=y2*h;
      altx:=x1;
      x1:=   x1*Cosin(phi) - y1*Sinus(phi);(* Drehen *)
      y1:= altx*Sinus(phi) + y1*Cosin(phi);
      altx:=x2;
      x2:=   x2*Cosin(phi) - y2*Sinus(phi);
      y2:= altx*Sinus(phi) + y2*Cosin(phi);
      x1:=x1+x;                            (* Verschieben *)
      x2:=x2+x;
      y1:=y1+y;
      y2:=y2+y;
   End;(* With *)
End;(* TransLinie *)

(**********************************************************************)
(*---------------Ausgabe eines einzelnen Zeichens---------------------*)
(*                                                                    *)
(* Quadrant=0: Zeichen mit seiner unten-links-Ecke am Bezugspunkt x,y *)
(* "       =1:  "      "   "      unten-rechts-Ecke "      "      x,y *)
(* "       =2:  "      "   "      oben-rechts-Ecke  "      "      x,y *)
(* "       =3:  "      "   "      oben-links-Ecke   "      "      x,y *)
(* w:ZeichenWeite                                                     *)
(* h:ZeichenHhe                                                      *)
(* phi:DrehWinkel                                                     *)
(**********************************************************************)

Procedure PrintCh(Var D:Text;Sprache:String;Ch:Char;Quadrant:QTyp;x,y,w,h,phi:Real);
Var
   Ende    :Boolean  ;
   Linie   :LinienTyp;
   LinienNr:Integer  ;
Begin
   Ende:=False;
   LinienNr:=0;
   While Not Ende Do Begin
      Linie:=Zeichensatz[Ord(Ch),LinienNr];{xxxxxxxxxx}
      Inc(LinienNr);
      If Linie.x1<-0.1 Then Ende:=True
      Else Begin
         Linie.x1:=Linie.x1/1000;
         Linie.y1:=Linie.y1/1000;
         Linie.x2:=Linie.x2/1000;
         Linie.y2:=Linie.y2/1000;
         Case Quadrant Of                    (* Zeichen so schieben,    *)
            0: TransLinie(Linie, 0, 0,1,1,0);(* da die richtige Ecke   *)
            1: TransLinie(Linie,-1, 0,1,1,0);(* die Koordinaten 0,0 hat *)
            2: TransLinie(Linie,-1,-1,1,1,0);
            3: TransLinie(Linie, 0,-1,1,1,0);
         End;(* Case *)
         TransLinie(Linie,x,y,w,h,phi);      (* erst dann drehen+schieben *)
         AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
      End;(* If Ende *)
   End;(* While Not Ende *)
End;(* PrintCh *)

(**********************************************************)
(*-------------Ausgabe eines Strings----------------------*)
(* Parameter:siehe PrintCh                                *)
(**********************************************************)

Procedure PrintStr(Var D:Text;Sprache:String;Str:String;Quadrant:QTyp;x,y,w,h,phi:Real);
Const
   ZeichenAbstand=0.2;
Var
   i:Integer;
Begin
   Case Quadrant Of
   0,3:Begin (* Von links nach rechts schreiben *)
          For i:=1 To Length(Str) Do Begin
             PrintCh(D,Sprache,Str[i],Quadrant,x,y,w,h,phi);
             x:=x+w*(1+Zeichenabstand)*Cosin(phi);
             y:=y+w*(1+Zeichenabstand)*Sinus(phi);
          End;(* For *)
     End;(* 1,4 *)
   1,2:Begin (* Von rechts nach links schreiben *)
          For i:=1 To Length(Str) Do Begin
             PrintCh(D,Sprache,Str[Length(Str)-i+1],Quadrant,x,y,w,h,phi);
             x:=x-w*(1+Zeichenabstand)*Cosin(phi);
             y:=y-w*(1+Zeichenabstand)*Sinus(phi);
          End;(* For *)
       End;(* 2,3 *)
    End;(* Case *)
End;(* PrintStr *)

(**********************************************************)
(* ------- Ausgabe einer Zahl --------------------------- *)
(* Zahl der Stellen: Gesamt                               *)
(* Zahl der Nachkommastellen: NachKomma                   *)
(**********************************************************)

Procedure PrintReal(Var D:Text;Sprache:String;Zahl:Real;Gesamt,NachKomma:Integer;Quadrant:QTyp;x,y,w,h,phi:Real);
Var
   Wort :String;
   Dummy:Integer;
Begin
   Str(Zahl:Gesamt:NachKomma,Wort);
   PrintStr(D,Sprache,Wort,Quadrant,x,y,w,h,phi);
End;(* PrintReal *)

(**********************************************************)
(*----------------- Ausgabe eines Kreises ----------------*)
(* mit Radius, Anfangs- und Endwinkel                     *)
(**********************************************************)

Procedure PrintCir(Var D:Text;Sprache:String;Radius,WinkelVon,WinkelBis:Real);
Const
   (* glob.Var.:HalbKreisWinkel *)
   WinkelInc=200.0;(* Jeden Halbkreis in 200 Linien zerlegen *)
Var
   Linie :LinienTyp;
   Winkel:Real     ;
Begin
   Winkel:=WinkelVon;
   While (Winkel<WinkelBis) Do Begin
      Linie.x1:=Radius*Cosin(Winkel);
      Linie.x2:=Radius*Cosin(Winkel+HalbKreisWinkel/WinkelInc);
      Linie.y1:=Radius*Sinus(Winkel);
      Linie.y2:=Radius*Sinus(Winkel+HalbKreisWinkel/WinkelInc);
      AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
      Winkel:=Winkel+(HalbKreisWinkel/WinkelInc);
   End;(* While *)
End;(* PrintCir *)

(**********************************************************)
(**********************************************************)
(*                                                        *)
(*                 "COMPILER-ROUTINEN"                    *)
(*                                                        *)
(**********************************************************)
(**********************************************************)

(**********************************************************)
(*----Ein Wort aus der Eingabedatei lesen-----------------*)
(**********************************************************)

Procedure LiesWort(Var EingabeDatei:Text;Var Wort:String);
Const
   DelMenge=[#32,#10,#13,#9];
   KommentarAnfang='{';
   KommentarEnde  ='}';
Var
   Ch:Char;
Begin
   Wort:='';
   Read(EingabeDatei,Ch);

   (* Leerzeichen am Wortanfang berlesen *)
   While (Ch In DelMenge) AND (Not EOF(EingabeDatei)) Do Begin

      Read(EingabeDatei,Ch);

      (* Kommentare einschlielich ihrer Klammern berlesen *)
      If (Ch=KommentarAnfang) AND NOT EOF(EingabeDatei) Then Begin
         Repeat
            Read(EingabeDatei,Ch);
         Until (Ch=KommentarEnde) OR EOF(EingabeDatei);
         If Not EOF(EingabeDatei) Then Read(EingabeDatei,Ch);
      End;(* If *)

   End;(* While *)

   (* eigentliches Wort lesen *)
   While (Not (Ch In DelMenge)) AND (Not EOF(EingabeDatei))
   Do Begin
      Wort:=Wort+Ch;
      Read(EingabeDatei,Ch);
   End;
End;(* LiesWort *)
(**********************************************************)
(*--- Ein Wort in Grobuchstaben umwandeln ---------------*)
(*---  (Es-Zett) wird nicht umgewandelt -----------------*)
(**********************************************************)

Procedure UpCaseWort(Var Wort:String);
Var
   Ch:Char   ;
   i :Integer;
Begin
   For i:=1 To Length(Wort) Do Begin
      Case Wort[i] Of
      (* Normale Kleinbuchstaben: *)
      'a'..'z':   Wort[i]:=UpCase(Wort[i]);
      (* In Groschrift vorhandene Akzente: *)
      '':        Wort[i]:='';
      '':        Wort[i]:='';
      '':        Wort[i]:='';      
      '':        Wort[i]:='';
      '':        Wort[i]:='';
      '':        Wort[i]:='';
      '':        Wort[i]:='';
      '':        Wort[i]:='';
      (* Nicht in Groschrift vorhandene Akzente : *)
      '','','':     Wort[i]:='A';
      '','','':     Wort[i]:='E';
      '','','':     Wort[i]:='O';
      '','','':     Wort[i]:='U';
      '':             Wort[i]:='Y';
      '','','','': Wort[i]:='I';
      End;(* Case *)
   End;
End;(* LiesUWort *)

(**********************************************************)
(*--- Ein Wort aus der Eingabedatei lesen und ------------*)
(*--- in Grobuchstaben umwandeln ------------------------*)
(**********************************************************)

Procedure LiesUWort(Var EingabeDatei:Text;Var Wort:String);
Var
   Ch:Char;
Begin
   LiesWort(EingabeDatei,Wort);
   UpCaseWort(Wort);
End;(* LiesUWort *)

(**********************************************************)
(*----Eine Zahl aus der Eingabedatei lesen----------------*)
(**********************************************************)


Procedure LiesZahl(Var EingabeDatei:Text;Var Zahl:Real);
Var
   Wort   :String ;
   ErrorNr:Integer;
Begin
   LiesUWort(EingabeDatei,Wort);
   Val(Wort,Zahl,ErrorNr);
   If ErrorNr<>0 Then Begin
      WriteLn('ERRORCODE #3');
      WriteLn('Zahlparameter enthielt falsches Zeichen:>',Wort,'<');
      WriteLn('Wrong character in numerical argument:>',Wort,'<');
      Halt;
   End;
End;(* LiesZahl *)

(**********************************************************)

Procedure LiesLinSkala(Var E,D:Text;Sprache:String;
                       BildWeite,BildHoehe:Real);
(*========================================================*)
   Procedure PrintLinSkala(Var D:Text;Sprache:String;BildWeite,BildHoehe:Real;
             Radius,WinkelVon,WinkelBis,
             ZahlVon,ZahlBis,ZahlAbst,Stellen,NachKomma,
             Dreh,Aussen,ZahlenHoehe,ZahlenWeite,ZahlenWinkel,LSZahl,ASZahl,
             LangAbst,LSLang,KurzAbst,LSKurz:Real);
   Var
      Winkel,Zahl:Real     ; (* Laufvariablen        *)
      Linie      :LinienTyp; (* Strich an der Zahl   *)
      xZahl      :Real     ; (* Koordinaten der Zahl *)
      yZahl      :Real     ;
      Quadrant   :QTyp     ;
      Negativ    :Boolean  ;
   Begin
       (****************************** Mittelpunkt zeichnen ***)
      Linie.x1:=-2;
      Linie.y1:=0;
      Linie.x2:=2;
      Linie.y2:=0;
      AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
      Linie.x1:=0;
      Linie.y1:=-2;
      Linie.x2:=0;
      Linie.y2:=2;
      AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
      (****************************** Vorkehrung, falls von>bis *)
      Negativ:=(ZahlVon>ZahlBis);
      If Negativ
      Then Begin
         ZahlAbst:=-Abs(ZahlAbst);
         LangAbst:=-Abs(LangAbst);
         KurzAbst:=-Abs(KurzAbst);
      End
      Else Begin
         ZahlAbst:=Abs(ZahlAbst);
         LangAbst:=Abs(LangAbst);
         KurzAbst:=Abs(KurzAbst);
      End;

      (****************************** Kreis ******************)
      PrintCir(D,Sprache,Radius,WinkelVon,WinkelBis);
      (****************************** Zahlen *****************)

      Zahl:=ZahlVon;
      While Negativ XOR (Zahl<=ZahlBis) Do Begin
         (********** Striche an den Zahlen **************)
         Winkel:=WinkelVon+(Zahl-ZahlVon)/(ZahlBis-ZahlVon)*(WinkelBis-WinkelVon);
         Linie.x1:=Radius*Cosin(Winkel);
         Linie.y1:=Radius*Sinus(Winkel);
         If (Aussen=1) Then Begin
            Linie.x2:=(Radius+LSZahl)*Cosin(Winkel);
            Linie.y2:=(Radius+LSZahl)*Sinus(Winkel);
         End
         Else Begin
            Linie.x2:=(Radius-LSZahl)*Cosin(Winkel);
            Linie.y2:=(Radius-LSZahl)*Sinus(Winkel);
         End;
         AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
         (********** Position der Zahlen berechnen ******)
         If (Aussen=1) Then Begin
            xZahl:=(Radius+LSZahl+ASZahl)*Cosin(Winkel);
            yZahl:=(Radius+LSZahl+ASZahl)*Sinus(Winkel);
         End
         Else Begin
            xZahl:=(Radius-LSZahl-ASZahl)*Cosin(Winkel);
            yZahl:=(Radius-LSZahl-ASZahl)*Sinus(Winkel);
         End;

         (********* Quadranten berechnen ****************)
         If Dreh=1 Then Begin (* Zahlen drehen sich mit *)
            If (Aussen=1)
            Then
               Quadrant:=NMOD(NTRUNC(-2*ZahlenWinkel/HalbKreisWinkel),4)
            Else
               Quadrant:=NMOD(1+NTRUNC(-2*ZahlenWinkel/HalbKreisWinkel),4);
         End
         Else Begin (* Zahlen drehen sich nicht mit *)
            Quadrant:=NMOD(NTRUNC(
                        2*(Winkel-ZahlenWinkel)/HalbKreisWinkel
                                  ),4);
            If NOT (Aussen=1)
            Then Quadrant:=NMOD(Quadrant+2,4);
         End;

         (*********** Ausgabe der Zahl ***************)
         If (Dreh=1)
         Then PrintReal(D,
                        Sprache,
                        Zahl,
                        Round(Stellen),
                        Round(NachKomma),
                        Quadrant,
                        xZahl,yZahl,
                        ZahlenWeite,ZahlenHoehe,
                        Winkel+ZahlenWinkel)
         Else PrintReal(D,
                        Sprache,
                        Zahl,
                        Round(Stellen),
                        Round(NachKomma),
                        Quadrant,
                        xZahl,yZahl,
                        ZahlenWeite,ZahlenHoehe,
                        ZahlenWinkel);
         Zahl:=Zahl+ZahlAbst;
      End;(* While *)

      (*///////////////////////////// Lange Striche /////////*)

      Zahl:=ZahlVon;
      While Negativ XOR (Zahl<=ZahlBis) Do Begin
         Winkel:=WinkelVon+(Zahl-ZahlVon)/(ZahlBis-ZahlVon)*(WinkelBis-WinkelVon);
         Linie.x1:=Radius*Cosin(Winkel);
         Linie.y1:=Radius*Sinus(Winkel);
         If (Aussen=1) Then Begin
            Linie.x2:=(Radius+LSLang)*Cosin(Winkel);
            Linie.y2:=(Radius+LSLang)*Sinus(Winkel);
         End
         Else Begin
            Linie.x2:=(Radius-LSLang)*Cosin(Winkel);
            Linie.y2:=(Radius-LSLang)*Sinus(Winkel);
         End;
         AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
         Zahl:=Zahl+LangAbst;
      End;(* While *)
      (*///////////////////////////// Kurze Striche /////////*)
      Zahl:=ZahlVon;
      While Negativ XOR (Zahl<=ZahlBis) Do Begin
         Winkel:=WinkelVon+(Zahl-ZahlVon)/(ZahlBis-ZahlVon)*(WinkelBis-WinkelVon);
         Linie.x1:=Radius*Cosin(Winkel);
         Linie.y1:=Radius*Sinus(Winkel);
         If (Aussen=1) Then Begin
            Linie.x2:=(Radius+LSKurz)*Cosin(Winkel);
            Linie.y2:=(Radius+LSKurz)*Sinus(Winkel);
         End
         Else Begin
            Linie.x2:=(Radius-LSKurz)*Cosin(Winkel);
            Linie.y2:=(Radius-LSKurz)*Sinus(Winkel);
         End;
         AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
         Zahl:=Zahl+KurzAbst;
      End;(* While *)
   End;(* PrintLinSkala *)

(*////////////////////////////////////////////////////////*)
 Var
   Radius     :Real;   (* Skala: wie gro *)
   WinkelVon  :Real;
   WinkelBis  :Real;
   ZahlVon    :Real;   (* Zahlen: welche *)
   ZahlBis    :Real;
   ZahlAbst   :Real;
   Stellen    :Real;   (* Zahlen: in welchem Format *)
   NachKomma  :Real;
   Dreh       :Real;   (* Zahlen: an welchem Punkt *)
   Aussen     :Real;
   ZahlenHoehe:Real;   (* Zahlen: wie gro *)
   ZahlenWeite:Real;
   ZahlenWinkel:Real;  (* Zahlen: welcher Winkel (bei phi=0) *)
   LSZahl     :Real;   (* Striche an den Zahlen *)
   ASZahl     :Real;
   LangAbst   :Real;   (* Lange Striche *)
   LSLang     :Real;
   KurzAbst   :Real;   (* Kurze Striche *)
   LSKurz     :Real;

   Wort       :String;
   SkalaEnde  :Boolean;
Begin
   (*//////// Defaults setzen /////////*)
   Radius     := 60;    WinkelVon  :=  0;    WinkelBis  :=360;
   ZahlVon    :=  0;    ZahlBis    := 99.99; ZahlAbst   := 10;
   Stellen    :=  2;    NachKomma  :=  0;    Dreh       :=  1;
   Aussen     :=  1;    ZahlenHoehe:=  5;    ZahlenWeite:=  2;
   ZahlenWinkel:= 0;
   LSZahl     :=  3;    ASZahl     :=  1;    LangAbst   :=  5;
   LSLang     :=  2;    KurzAbst   :=  1;    LSKurz     :=  1;
   (*//////// Parameter abfragen //////*)
   SkalaEnde:=False;
   While Not(EOF(E) Or SkalaEnde) Do Begin
      LiesUWort(E,Wort);
      If      (Wort='RADIUS')    OR (Wort='RADIUS')     Then LiesZahl(E,Radius)
      Else If (Wort='WINKELVON') OR (Wort='ANGLEFROM')  Then LiesZahl(E,WinkelVon)
      Else If (Wort='WINKELBIS') OR (Wort='ANGLETO')  	Then LiesZahl(E,WinkelBis)
      Else If (Wort='ZAHLVON')   OR (Wort='NUMBERFROM')	Then LiesZahl(E,ZahlVon)
      Else If (Wort='ZAHLBIS')   OR (Wort='NUMBERTO')  	Then LiesZahl(E,ZahlBis)
      Else If (Wort='ZAHLABST')  OR (Wort='NUMBERDIST')	Then LiesZahl(E,ZahlAbst)
      Else If (Wort='STELLEN')   OR (Wort='NODIGITS')   Then LiesZahl(E,Stellen)
      Else If (Wort='NACHKOMMA') OR (Wort='NODIGFRAC')	Then LiesZahl(E,NachKomma)
      Else If (Wort='DREH')      OR (Wort='TURN')   	Then LiesZahl(E,Dreh)
      Else If (Wort='AUSSEN')    OR (Wort='OUTSIDE')   	Then LiesZahl(E,Aussen)
      Else If (Wort='ZAHLENHOEHE') OR (Wort='DIGITHEIGHT') 	Then LiesZahl(E,ZahlenHoehe)
      Else If (Wort='ZAHLENWEITE') OR (Wort='DIGITWIDTH') 	Then LiesZahl(E,ZahlenWeite)
      Else If (Wort='ZAHLENWINKEL') OR (Wort='DIGITANGLE')	Then LiesZahl(E,ZahlenWinkel)
      Else If (Wort='LSZAHL')   OR (Wort='LENGTHDIGITTICK')	Then LiesZahl(E,LSZahl)
      Else If (Wort='ASZAHL')   OR (Wort='DISTTICKDIGIT')    	Then LiesZahl(E,ASZahl)
      Else If (Wort='LANGABST') OR (Wort='LONGNUMBERDIST')    	Then LiesZahl(E,LangAbst)
      Else If (Wort='LSLANG')   OR (Wort='LENGTHLONGTICK')    	Then LiesZahl(E,LSLang)
      Else If (Wort='KURZABST') OR (Wort='SHORTNUMBERDIST')    	Then LiesZahl(E,KurzAbst)
      Else If (Wort='LSKURZ')   OR (Wort='LENGTHSHORTTICK')	Then LiesZahl(E,LSKurz)
      Else If (Wort='ENDSKALA') OR (Wort='ENDDIAL')    	Then SkalaEnde:=True
      Else Begin
         WriteLn('ERRORCODE #2');
         WriteLn('Unbekanntes Wort in der Eingabedatei aufgetreten:>',Wort,'<');
         WriteLn('Unknown word in input file:>',Wort,'<');
      End;(* Else *)
   End;(* While *)
   PrintLinSkala(D,Sprache,BildWeite,BildHoehe,
                 Radius,WinkelVon,WinkelBis,
                 ZahlVon,ZahlBis,ZahlAbst,Stellen,NachKomma,
                 Dreh,Aussen,ZahlenHoehe,ZahlenWeite,ZahlenWinkel,
                 LSZahl,ASZahl,
                 LangAbst,LSLang,KurzAbst,LSKurz);
End;(* LiesLinSkala *)


(***********************************************************)
(***********************************************************)
(*                                                         *)
(* Skala ausgeben, deren Eichpunkte in LIST gesammelt sind *)
(*                                                         *)
(***********************************************************)
(***********************************************************)


Procedure LiesEichSkala(Var E,D:Text;Sprache:String;
                        BildWeite,BildHoehe:Real);
Const
   ListMax=100;
Type
   LTyp = Record
             Anzahl:Integer                   ;
             Wert  :Array [0..ListMax] Of Real;
             Winkel:Array [0..ListMax] Of Real;
          End;
(*========================================================*)
   Procedure LiesList(Var E:Text;Var List:LTyp);
   Var
      Wort:String;
      FehlerCode:Integer;
   Begin
      With List Do Begin
         LiesUWort(E,Wort);                               (* 1.Wort lesen   *)
         While NOT (EOF(E) OR (Wort='ENDLIST') OR (Wort='ENDLIST')) 
         Do Begin (* 1.Wort test    *)
            Val( Wort,Wert[Anzahl],FehlerCode);          (* 1.Wort wandeln *)
            If FehlerCode<>0 Then Begin
               WriteLn('ERRORCODE #6: Fehler in Liste/error within list:');
               WriteLn('>',Wort,'<');
            End;
            LiesUWort(E,Wort);                             (* 2.Wort lesen   *)
            If NOT (EOF(E) OR (Wort='ENDLIST') OR (Wort='ENDLIST'))
            Then Begin (* 2.Wort test    *)
               Val( Wort,Winkel[Anzahl],FehlerCode);      (* 2.Wort wandeln *)
               If FehlerCode<>0 Then Begin
                  WriteLn('ERRORCODE #7: Fehler in Liste/error within list:');
                  WriteLn('>',Wort,'<');
               End;
               Inc(Anzahl);
               LiesUWort(E,Wort);                         (* 1.Wort lesen   *)
            End;(* If *)
         End;(* While *)
      End;(* With *)
   End;(* LiesList *)
(*========================================================*)
   Procedure PrintEichSkala(
             Var D:Text;Sprache:String;BildWeite,BildHoehe:Real;
             Radius,WinkelVon,WinkelBis:Real;List:LTyp;Stellen,NachKomma,
             Dreh,Aussen,ZahlenHoehe,ZahlenWeite,ZahlenWinkel,LSZahl,ASZahl,
             LangAbst,LSLang,KurzAbst,LSKurz:Real);
   Var
      LWinkel    :Real     ; (* Laufvariablen        *)
      LZahl      :Real     ;
      Lauf       :Integer  ;
      Linie      :LinienTyp; (* Strich an der Zahl   *)
      xZahl      :Real     ; (* Koordinaten der Zahl *)
      yZahl      :Real     ;
      Quadrant   :QTyp     ;
      Negativ    :Boolean  ;
   Begin
       (*----------------------------- Mittelpunkt zeichnen --*)
      Linie.x1:=-2;
      Linie.y1:=0;
      Linie.x2:=2;
      Linie.y2:=0;
      AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
      Linie.x1:=0;
      Linie.y1:=-2;
      Linie.x2:=0;
      Linie.y2:=2;
      AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);

      (****************************** Kreis ******************)
      PrintCir(D,Sprache,Radius,WinkelVon,WinkelBis);

      (****************************** Zahlen *****************)

      (********** Striche an den Zahlen **************)
      For Lauf:=0 To (List.Anzahl-1) Do Begin
         Linie.x1:=Radius*Cosin(List.Winkel[Lauf]);
         Linie.y1:=Radius*Sinus(List.Winkel[Lauf]);
         If (Aussen=1) Then Begin
            Linie.x2:=(Radius+LSZahl)*Cosin(List.Winkel[Lauf]);
            Linie.y2:=(Radius+LSZahl)*Sinus(List.Winkel[Lauf]);
         End
         Else Begin
            Linie.x2:=(Radius-LSZahl)*Cosin(List.Winkel[Lauf]);
            Linie.y2:=(Radius-LSZahl)*Sinus(List.Winkel[Lauf]);
         End;
         AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);

         (********** Position der Zahlen berechnen ******)

         If (Aussen=1) Then Begin
            xZahl:=(Radius+LSZahl+ASZahl)*Cosin(List.Winkel[Lauf]);
            yZahl:=(Radius+LSZahl+ASZahl)*Sinus(List.Winkel[Lauf]);
         End
         Else Begin
            xZahl:=(Radius-LSZahl-ASZahl)*Cosin(List.Winkel[Lauf]);
            yZahl:=(Radius-LSZahl-ASZahl)*Sinus(List.Winkel[Lauf]);
         End;
         (********* Quadranten berechnen ****************)

         If Dreh=1 Then Begin (* Zahlen drehen sich mit *)
            If (Aussen=1)
            Then
               Quadrant:=NMOD(NTRUNC(-2*ZahlenWinkel/HalbKreisWinkel),4)
            Else
               Quadrant:=NMOD(1+NTRUNC(-2*ZahlenWinkel/HalbKreisWinkel),4);
         End
         Else Begin (* Zahlen drehen sich nicht mit *)
            Quadrant:=NMOD(NTRUNC(
                        2*(List.Winkel[Lauf]-ZahlenWinkel)/HalbKreisWinkel
                                  ),4);
            If NOT (Aussen=1)
            Then Quadrant:=NMOD(Quadrant+2,4);
         End;

         (********* Ausgabe der Zahl ********************)
         If (Dreh=1)
         Then PrintReal(D,
                        Sprache,
                        List.Wert[Lauf],
                        Round(Stellen),
                        Round(NachKomma),
                        Quadrant,
                        xZahl,yZahl,
                        ZahlenWeite,ZahlenHoehe,
                        List.Winkel[Lauf]+ZahlenWinkel)
         Else PrintReal(D,
                        Sprache,
                        List.Wert[Lauf],
                        Round(Stellen),
                        Round(NachKomma),                     
                        Quadrant,
                        xZahl,yZahl,
                        ZahlenWeite,ZahlenHoehe,  
                        ZahlenWinkel);       
         End;(* While *)      

      (*-----------------------------------------------------*)      
      (*----------------------------- Fr jedes Intervall:---*)      
      (*-----------------------------------------------------*)       

      For Lauf:=0 To List.Anzahl-2 Do Begin

         Negativ:=(List.Wert[Lauf]>List.Wert[Lauf+1]);
         If Negativ
         Then Begin
            LangAbst:=-Abs(LangAbst);(* Negatives Inkrement *)
            KurzAbst:=-Abs(KurzAbst);
         End
         Else Begin
            LangAbst:=Abs(LangAbst);(* Positives Inkrement *)
            KurzAbst:=Abs(KurzAbst);
         End;
      (*----------------------------- Lange Striche ---------*)

         LZahl:=List.Wert[Lauf];
         While Negativ XOR (LZahl<=List.Wert[Lauf+1]) Do Begin
            With List Do LWinkel:=Winkel[Lauf]
                         +(LZahl-Wert[Lauf])/(Wert[Lauf+1]-Wert[Lauf])
                         *(Winkel[Lauf+1]-Winkel[Lauf]);
            Linie.x1:=Radius*Cosin(LWinkel);
            Linie.y1:=Radius*Sinus(LWinkel);
            If (Aussen=1) Then Begin
               Linie.x2:=(Radius+LSLang)*Cosin(LWinkel);
               Linie.y2:=(Radius+LSLang)*Sinus(LWinkel);
            End
            Else Begin
               Linie.x2:=(Radius-LSLang)*Cosin(LWinkel);
               Linie.y2:=(Radius-LSLang)*Sinus(LWinkel);
            End;
            AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
            LZahl:=LZahl+LangAbst;
         End;(* While *)

         (*----------------------------- Kurze Striche ---------*)

         LZahl:=List.Wert[Lauf];
         While Negativ XOR (LZahl<=List.Wert[Lauf+1]) Do Begin
            With List Do LWinkel:=Winkel[Lauf]
                         +(LZahl-Wert[Lauf])/(Wert[Lauf+1]-Wert[Lauf])
                         *(Winkel[Lauf+1]-Winkel[Lauf]);
            Linie.x1:=Radius*Cosin(LWinkel);
            Linie.y1:=Radius*Sinus(LWinkel);
            If (Aussen=1) Then Begin
               Linie.x2:=(Radius+LSKurz)*Cosin(LWinkel);
               Linie.y2:=(Radius+LSKurz)*Sinus(LWinkel);
            End
            Else Begin
               Linie.x2:=(Radius-LSKurz)*Cosin(LWinkel);
               Linie.y2:=(Radius-LSKurz)*Sinus(LWinkel);
            End;
            AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
            LZahl:=LZahl+KurzAbst;
         End;(* While *)
      End;(* For *)
   End;(* PrintEichSkala *)
(*========================================================*)
 Var
   Radius     :Real;   (* Skala: wie gro *)
   WinkelVon  :Real;
   WinkelBis  :Real;
   List       :LTyp;   (* Liste mit Eichpunkten *)
   Stellen    :Real;   (* Zahlen: in welchem Format *)
   NachKomma  :Real;
   Dreh       :Real;   (* Zahlen: an welchem Punkt *)
   Aussen     :Real;
   ZahlenHoehe:Real;   (* Zahlen: wie gro *)
   ZahlenWeite:Real;
   ZahlenWinkel:Real;  (* Zahlen: welcher Winkel *)
   LSZahl     :Real;   (* Striche an den Zahlen *)
   ASZahl     :Real;
   LangAbst   :Real;   (* Lange Striche *)
   LSLang     :Real;
   KurzAbst   :Real;   (* Kurze Striche *)
   LSKurz     :Real;

   Wort       :String;
   SkalaEnde  :Boolean;
Begin
   (*-------- Defaults setzen ---------*)
   Radius     := 50;    WinkelVon  :=  0;    WinkelBis  :=360;
   List.Anzahl:=  0;
   Stellen    :=  2;    NachKomma  :=  0;    Dreh       :=  1;
   Aussen     :=  1;    ZahlenHoehe:=  4;    ZahlenWeite:=  2;
   ZahlenWinkel:= 0;
   LSZahl     :=  3;    ASZahl     :=  1;    LangAbst   :=  2;
   LSLang     :=  2;    KurzAbst   :=  1;    LSKurz     :=  1;
   (*-------- Parameter abfragen ------*)
   SkalaEnde:=False;
   While Not(EOF(E) Or SkalaEnde) Do Begin
      LiesUWort(E,Wort);
      If      (Wort='RADIUS')    OR (Wort='RADIUS')		Then LiesZahl(E,Radius)      
      Else If (Wort='LIST')      OR  (Wort='LIST')		Then LiesList(E,List)
      Else If (Wort='WINKELVON') OR (Wort='ANGLEFROM')  	Then LiesZahl(E,WinkelVon)
      Else If (Wort='WINKELBIS') OR (Wort='ANGLETO')  		Then LiesZahl(E,WinkelBis)
      Else If (Wort='STELLEN')   OR (Wort='NODIGITS')   	Then LiesZahl(E,Stellen)
      Else If (Wort='NACHKOMMA') OR (Wort='NODIGFRAC')		Then LiesZahl(E,NachKomma)
      Else If (Wort='DREH')      OR (Wort='TURN')   		Then LiesZahl(E,Dreh)
      Else If (Wort='AUSSEN')    OR (Wort='OUTSIDE') 		Then LiesZahl(E,Aussen)
      Else If (Wort='ZAHLENHOEHE') OR (Wort='DIGITHEIGHT') 	Then LiesZahl(E,ZahlenHoehe)
      Else If (Wort='ZAHLENWEITE') OR (Wort='DIGITWIDTH') 	Then LiesZahl(E,ZahlenWeite)
      Else If (Wort='ZAHLENWINKEL') OR (Wort='DIGITANGLE')	Then LiesZahl(E,ZahlenWinkel)
      Else If (Wort='LSZAHL')   OR (Wort='LENGTHDIGITTICK')	Then LiesZahl(E,LSZahl)
      Else If (Wort='ASZAHL')   OR (Wort='DISTTICKDIGIT')    	Then LiesZahl(E,ASZahl)
      Else If (Wort='LANGABST') OR (Wort='LONGNUMBERDIST')    	Then LiesZahl(E,LangAbst)
      Else If (Wort='LSLANG')   OR (Wort='LENGTHLONGTICK')    	Then LiesZahl(E,LSLang)
      Else If (Wort='KURZABST') OR (Wort='SHORTNUMBERDIST')    	Then LiesZahl(E,KurzAbst)
      Else If (Wort='LSKURZ')   OR (Wort='LENGTHSHORTTICK')	Then LiesZahl(E,LSKurz)
      Else If (Wort='ENDSKALA') OR (Wort='ENDDIAL')	    	Then SkalaEnde:=True
      Else Begin
         WriteLn('ERRORCODE #5');
         WriteLn('Unbekanntes Wort in der Eingabedatei aufgetreten:>',Wort,'<');
         WriteLn('Unknown word in input file:>',Wort,'<');
      End;(* Else *)
   End;(* While *)
   PrintEichSkala(D,Sprache,BildWeite,BildHoehe,
                 Radius,WinkelVon,WinkelBis,List,Stellen,NachKomma,
                 Dreh,Aussen,ZahlenHoehe,ZahlenWeite,ZahlenWinkel,LSZahl,ASZahl,
                 LangAbst,LSLang,KurzAbst,LSKurz);
End;(* LiesEichSkala *)

(**********************************************************)
(**********************************************************)

Procedure LiesSchrift(Var E,D:Text;Sprache:String;BildWeite,BildHoehe:Real);
Var
   Wort,UWort:String;
   SchriftZug:String;
   XSchrift  :Real;
   YSchrift  :Real;
   WSchrift  :Real;
   HSchrift  :Real;
   phiSchrift:Real;
   TMP       :Real;
   SchriftQuadrant:QTyp;
Begin
   XSchrift  := 0;
   YSchrift  :=10;
   WSchrift  := 5;
   HSchrift  :=10;
   phiSchrift:= 0;
   SchriftQuadrant:=0;
   WriteLn;
   LiesUWort(E,Wort);
   While Not(EOF(E) Or (Wort='STARTSCHRIFT') OR (Wort='STARTSTRING')) Do Begin
      If      (Wort='XSCHRIFT')   OR (Wort='XSTRING')      Then LiesZahl(E,XSchrift)
      Else If (Wort='YSCHRIFT')   OR (Wort='YSTRING')      Then LiesZahl(E,YSchrift)
      Else If (Wort='WSCHRIFT')   OR (Wort='WSTRING')      Then LiesZahl(E,WSchrift)
      Else If (Wort='HSCHRIFT')   OR (Wort='HSTRING')      Then LiesZahl(E,HSchrift)
      Else If (Wort='PHISCHRIFT') OR (Wort='ANGLESTRING')  Then LiesZahl(E,phiSchrift)
      Else If (Wort='QSCHRIFT')   OR (Wort='QSTRING')
      Then Begin
         LiesZahl(E,TMP);
         SchriftQuadrant:=NMOD(TRUNC(TMP),4);
      End
      Else Begin
         WriteLn('ERRORCODE #8');
         WriteLn('Unbekanntes Wort als Schriftparameter aufgetreten:>',Wort,'<');
         WriteLn('Unknown word for string argument:>',Wort,'<');
      End;(* Else *)
      LiesUWort(E,Wort);
   End;(* While *)

   SchriftZug:='';
   LiesWort(E,Wort);
   UWort:=Wort;
   UpCaseWort(UWort);
   If NOT EOF(E) Then Begin

      While NOT (EOF(E) OR (UWort='ENDSCHRIFT') OR (Wort='ENDSTRING')) Do 
      Begin
         If Length(SchriftZug)<>0 Then SchriftZug:=SchriftZug+' ';
         SchriftZug:=SchriftZug+Wort;
         LiesWort(E,Wort);
         UWort:=Wort;
         UpCaseWort(UWort);
      End;(* While *)
   End;(* If *)

   PrintStr(D,Sprache,SchriftZug,SchriftQuadrant,
            xSchrift,ySchrift,wSchrift,hSchrift,phiSchrift);
End;(* LiesSchrift *)

(**********************************************************)
(**********************************************************)

Procedure LiesEcho(Var E:Text);
Var
   Wort,UWort:String;
   Zahl,FehlerCode:Integer;
Begin
   WriteLn;
   LiesWort(E,Wort);
   UWort:=Wort;
   UpCaseWort(UWort);
   While NOT (EOF(E) OR (UWort='ENDECHO') OR (UWort='ENDECHO')) Do Begin
      If (Wort[1]='#') AND (Length(Wort)>1)
      Then Begin
         Wort:=Copy(Wort,2,Length(Wort)-1);
         Val(Wort,Zahl,FehlerCode);
         If FehlerCode<>0 Then Begin
            WriteLn('ERRORCODE #7: Fehler in Zahlenkonstante/error in numerical constant:');
            WriteLn('>',Wort,'<');
         End
         Else Write(Chr(Zahl));
      End
      Else Begin
         Write(Wort);
         Write(' ');
      End;
      LiesWort(E,Wort);
      UWort:=Wort;
      UpCaseWort(UWort);
   End;
   WriteLn;
End;(* LiesEcho *)

(**********************************************************)
(**********************************************************)

Procedure LiesLinie(Var E,D:Text;Sprache:String;BildWeite,BildHoehe:Real);
Var
   Linie:LinienTyp;
Begin
   LiesZahl(E,Linie.x1);
   If NOT EOF(E) Then
      LiesZahl(E,Linie.y1);
      If NOT EOF(E) Then
         LiesZahl(E,Linie.x2);
            If NOT EOF(E)
            Then Begin
               LiesZahl(E,Linie.y2);
               AusLinie(D,Sprache,Linie,BildWeite,BildHoehe);
            End;
End;(* LiesLinie *)

(**********************************************************)
(**********************************************************)

Procedure LiesKreis(Var E,D:Text;Sprache:String;BildWeite,BildHoehe:Real);
Var
   Radius, WinkelVon, WinkelBis: Real;
Begin
   LiesZahl(E,Radius);
   If NOT EOF(E) Then
      LiesZahl(E,WinkelVon);
      If NOT EOF(E) Then Begin
         LiesZahl(E,WinkelBis);
         (* AusLinie(D,Sprache,Linie,BildWeite,BildHoehe); *)
         PrintCir(D,Sprache,Radius,WinkelVon,WinkelBis);
     End;
End;(* LiesKreis *)

(**********************************************************)
(**********************************************************)


(**********************************************************)
(**********************************************************)
(*                                                        *)
(*                     Hauptprogramm                      *)
(*                                                        *)
(**********************************************************)
(**********************************************************)

Begin (* Main *)
   (*********************************** Mitteilung *)
   WriteLn('Skala Version 1.20 (2003/12/30)');
   (*********************************** Globale Variablen initialisieren *)
   Sprache        :='HPGL';(* Default: Ausgabe auf Bildschirm *)
   Spiegel	  :='OFF' ;(* Default: nicht spiegeln *) 
 
   BildWeite      := 250 ; (* Default: A4 quer (HPGL)         *)
   BildHoehe      := 180 ;
   HalbkreisWinkel:= 180 ; (* Default: AltGrad: 180= *)
   ZeichenSatzInit(Zeichensatz);
   WriteLn('Zeichensatz wurde initialisiert/font has been initialized');
   (*********************************** Eingabedatei ffnen *)
   If ParamCount>0 Then Begin
      EinDateiName:=ParamStr(1);
   End
   Else Begin
      Repeat
         Write('Bitte den Namen der Eingabedatei eingeben/please enter name of input file:');
         ReadLn(EinDateiName);
         If EinDateiName='' Then Writeln('Dieser Dateiname ist ungltig/error with name of input file.');
      Until(EinDateiName<>'');
   End;
   {$I-}
      Assign(E,EinDateiName);
      ReSet(E);
   {$I+}
   If (IOResult<>0) Then Begin
      WriteLn('ERRORCODE #0');
      WriteLn('Die angegebene Eingabedatei ist nicht vorhanden oder sie lt sich nicht ffnen.');
      WriteLn('Could not open input file (maybe not existent?)');
      Halt;
   End;
   (*********************************** Ausgabedatei ffnen *)
   If ParamCount>1 Then Begin
      AusDateiName:=ParamStr(2);
   End
   Else Begin
      Repeat
         Write('Bitte den Namen der Ausgabedatei eingeben/please enter name of output file:');
         ReadLn(AusDateiName);
         If AusDateiName='' Then Writeln('Dieser Dateiname ist ungltig/error with name of output file.');
      Until(AusDateiName<>'');
   End;
   {$I-}
      Assign(D,AusDateiName);
      ReWrite(D);
   {$I+}
   If (IOResult<>0) Then Begin
      WriteLn('ERRORCODE #9');
      WriteLn('Die angegebene Ausgabedatei lt sich nicht ffnen/could not open output file.');
      Halt;
   End;
   (*********************************** Eingabedatei lesen *)
   While Not EOF(E) Do Begin

      LiesUWort(E,Wort);

      If NOT EOF(E) Then
      If      (Wort='SPRACHE')   OR (Wort='LANGUAGE')   Then LiesUWort(E,Sprache)
      Else If (Wort='SPIEGEL')   OR (Wort='MIRROR')  	Then LiesUWort(E,Spiegel)
      Else If (Wort='BILDHOEHE') OR (Wort='PICHEIGHT')	Then LiesZahl(E,BildWeite)
      Else If (Wort='BILDWEITE') OR (Wort='PICWIDTH')	Then LiesZahl(E,BildHoehe)
      Else If (Wort='INIT')      OR (Wort='INIT')	Then AusgabeInit(D,Sprache,BildWeite,BildHoehe)
      Else If (Wort='PI')        OR (Wort='PI')		Then LiesZahl(E,HalbkreisWinkel)
      Else If (Wort='LINSKALA')  OR (Wort='LINDIAL')	Then LiesLinSkala(E,D,Sprache,BildWeite,BildHoehe)
      Else If (Wort='EICHSKALA') OR (Wort='ALIGNDIAL')	Then LiesEichSkala(E,D,Sprache,BildWeite,BildHoehe)
      Else If (Wort='SCHRIFT')   OR (Wort='STRING')	Then LiesSchrift(E,D,Sprache,BildWeite,BildHoehe)
      Else If (Wort='LINIE')     OR (Wort='LINE')	Then LiesLinie(E,D,Sprache,BildWeite,BildHoehe)
      Else If (Wort='KREIS')     OR (Wort='CIRCLE')	Then LiesKreis(E,D,Sprache,BildWeite,BildHoehe)
      Else If (Wort='ECHO')      OR (Wort='ECHO')	Then LiesEcho(E)
      Else Begin (**************************** Fehler *********************)
         WriteLn('ERRORCODE #1');
         WriteLn('Unbekanntes Wort in der Eingabedatei aufgetreten:>',Wort,'<');
         WriteLn('Unknown word in input file:>',Wort,'<');
      End;(* If-Else-Kette *)
   End;(* While Not EOF *)

   AusgabeExit(Sprache);
End.
